.. mplhep documentation master file, created by
   sphinx-quickstart on Sun Apr 12 14:08:38 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.


======
mplhep
======

A `matplotlib <https://matplotlib.org/>`__ wrapper for easy plotting required in
high energy physics (HEP). Primarily "prebinned" 1D & 2D histograms and matplotlib
`style-sheets <https://matplotlib.org/3.1.1/gallery/style_sheets/style_sheets_reference.html>`__
carrying recommended plotting styles of large LHC experiments - ATLAS, CMS & LHCb.
This project is published `on GitHub <https://github.com/scikit-hep/mplhep>`__.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   install

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   guide

Work-in-progress

.. toctree::
   :maxdepth: 2
   :caption: Reference

   api

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
